@@ -8,8 +8,6 @@ import scipy.sparse as sp
 from graphgallery.utils.data_utils import normalize_adj
 
 # ChebyGCN
-
-
 def chebyshev_polynomials(adj, rate=-0.5, order=3):
     """Calculate Chebyshev polynomials up to order k. Return a list of sparse matrices (tuple representation)."""
 
@@ -33,15 +31,19 @@ def chebyshev_polynomials(adj, rate=-0.5, order=3):
     return t_k
 
 # FASTGCN
-
-
 def column_prop(adj):
     column_norm = sp.linalg.norm(adj, axis=0)
     norm_sum = column_norm.sum()
     return column_norm/norm_sum
 
-# LGCN
-def solve_cudnn_error():
+def set_memory_growth():
+    """Set if memory growth should be enabled for ALL `PhysicalDevice`.
+
+    If memory growth is enabled for ALL `PhysicalDevice`, the runtime initialization
+    will not allocate all memory on the device. Memory growth cannot be configured
+    on a `PhysicalDevice` with virtual devices configured.
+
+    """
     gpus = tf.config.experimental.list_physical_devices('GPU')
     if gpus:
         try:
